<!--
  ~ Copyright 2005-2007 WSO2, Inc. (http://wso2.com)
  ~
  ~ Licensed under the Apache License, Version 2.0 (the "License");
  ~ you may not use this file except in compliance with the License.
  ~ You may obtain a copy of the License at
  ~
  ~ http://www.apache.org/licenses/LICENSE-2.0
  ~
  ~ Unless required by applicable law or agreed to in writing, software
  ~ distributed under the License is distributed on an "AS IS" BASIS,
  ~ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  ~ See the License for the specific language governing permissions and
  ~ limitations under the License.
  -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html"/>
    <!-- Value of resourceHTTPEPR will be injected via javascript -->
    <xsl:param name="resourceHTTPEPR"/>

    <xsl:template match="ns1:listServiceGroupsResponse" xmlns:ns1="http://org.apache.axis2/xsd">
        <xsl:choose>
            <xsl:when test="return">
                <table class="styled" id="service_groups_info_table">
                    <thead>
                        <tr>
                            <th>Service Groups</th>
                            <th>Actions</th>
                            <th>Services</th>
							<!--<th>Service Type</th>-->
                            <!-- Service type has removed until things being finalize -->
                            <th>View</th>
                        </tr>
                    </thead>
                    <tbody>
                        <xsl:for-each select="return">
                            <tr>
                                <td>
                                    <xsl:attribute name="rowspan">
                                        <xsl:value-of select="count(services) + 1"/>
                                    </xsl:attribute>
                                        <a>
                                            <xsl:attribute name="href">#</xsl:attribute>
                                            <xsl:attribute name="onclick">javascript:showServiceGroupInfo('<xsl:value-of select="group_name"/>'); return false;</xsl:attribute>
                                            <xsl:attribute name="title">Show Service Group <xsl:value-of select="group_name"/></xsl:attribute>
                                            <xsl:value-of select="group_name"/>
                                        </a>
                                </td>
                                <td>
                                    <xsl:attribute name="rowspan"><xsl:value-of select="count(services) + 1"/></xsl:attribute>
                                    <nobr>
                                        &#160;&#160;
                                        <a href="#" id="cancel_link">
                                            <xsl:attribute name="onClick">javascript:deleteServiceGroup('<xsl:value-of select="group_name"/>'); return false;</xsl:attribute>
                                            <xsl:attribute name="title">Remove <xsl:value-of select="group_name"/>Service Group</xsl:attribute>
                                            <xsl:attribute name="alt">Remove</xsl:attribute>
                                            &#160;&#160;&#160;&#160;
                                        </a>
                                    </nobr>
                                </td>
                                <td/>
                            </tr>
                            <xsl:variable name="service_context_path"><xsl:value-of select="serviceContextPath"/></xsl:variable>
                            <xsl:for-each select="services">
                                <xsl:sort/>
                                <tr>
                                    <td>
                                        <a>
                                            <xsl:attribute name="href">#</xsl:attribute>
                                            <xsl:attribute name="onClick">javascript:listServiceDataRefresh('<xsl:value-of select="."/>'); return false;</xsl:attribute>
                                            <xsl:value-of select="."/>
                                        </a>
                                    </td>
                                    <!--<td>
										<xsl:variable name="parentEle" select=".."/>
										<xsl:variable name="serviceName" select="."/>
										<xsl:apply-templates select="$parentEle/serviceTypes">
											<xsl:with-param name="serviceNameParam" select="$serviceName"/>
										</xsl:apply-templates>
                                    </td>-->
                                    <!-- TODO fix for static EPR-->
                                    <td style="width: 200px;">
                                        <a>
                                            <xsl:attribute name="href"><xsl:value-of select="$resourceHTTPEPR"/><xsl:value-of select="."/>?wsdl&amp;annotation=true</xsl:attribute>
                                            <xsl:attribute name="target">_blank</xsl:attribute>
                                            <xsl:text>WSDL&#160;1.1</xsl:text>
                                        </a>
                                        <xsl:text>&#160;&#160;</xsl:text>
                                        <a>
                                            <xsl:attribute name="href"><xsl:value-of select="$resourceHTTPEPR"/><xsl:value-of select="."/>?wsdl2&amp;annotation=true</xsl:attribute>
                                            <xsl:attribute name="target">_blank</xsl:attribute>
                                            <xsl:text>WSDL&#160;2.0</xsl:text>
                                        </a>
                                        <xsl:text>&#160;&#160;&#160;</xsl:text>
                                        <a>
                                            <xsl:attribute name="href"><xsl:value-of select="$resourceHTTPEPR"/><xsl:value-of select="."/>?xsd&amp;annotation=true</xsl:attribute>
                                            <xsl:attribute name="target">_blank</xsl:attribute>
                                            <xsl:text>Schema</xsl:text>
                                        </a>
                                        <xsl:text>&#160;&#160;&#160;</xsl:text>
                                        <a>
                                            <xsl:attribute name="href"><xsl:value-of select="$resourceHTTPEPR"/><xsl:value-of select="."/>?policy</xsl:attribute>
                                            <xsl:attribute name="target">_blank</xsl:attribute>
                                            <xsl:text>Policy</xsl:text>
                                        </a>
                                        <xsl:text>&#160;&#160;&#160;</xsl:text>
                                        <a>
                                            <xsl:attribute name="href">#</xsl:attribute>
                                            <xsl:attribute name="onClick">javascript:openWindowHTTP('<xsl:value-of select="."/>?cert');return false;</xsl:attribute>
                                            <xsl:attribute name="target">_blank</xsl:attribute>
                                            <xsl:text>Certificate</xsl:text>
                                        </a>
                                    </td>
                                </tr>
                            </xsl:for-each>
                        </xsl:for-each>
                    </tbody>
                </table>
			</xsl:when>
            <xsl:otherwise>
                <b>
                    <i>No Active Services</i>
                </b>
            </xsl:otherwise>

        </xsl:choose>
    </xsl:template>
	
    <xsl:template match="serviceTypes">
		<xsl:param name="serviceNameParam"/>
	    <xsl:for-each select=".">
            <xsl:variable name="serviceType" select="."/>
            <xsl:variable name="seperator">#</xsl:variable>	
            <xsl:variable name="serviceName" select="substring-before($serviceType,$seperator)" />
		    <xsl:if test="$serviceNameParam = $serviceName">
	    	       <xsl:value-of select="substring-after($serviceType,$seperator)"/>
	    	</xsl:if>
        </xsl:for-each>
    </xsl:template>	
</xsl:stylesheet>